==> haskell-persistent-postgresql-2.13.4.1-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.4.1
visibility:           public
id:                   persistent-postgresql-2.13.4.1-6GawNwpNJERAT9KlJymLdc
key:                  persistent-postgresql-2.13.4.1-6GawNwpNJERAT9KlJymLdc
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  336c7eb8a9737081e77b2109e251fb87
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.4.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.4.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.4.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.4.1-6GawNwpNJERAT9KlJymLdc
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    conduit-1.3.6.1-86fl8mgs0PcICSp2A4xyva containers-0.6.7
    monad-logger-0.3.41-CIGkCI7Ls7GAj2aHWa5Aio mtl-2.2.2
    persistent-2.14.5.1-4wEblN81BcPGJ8VjtmLirA
    postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1
    postgresql-simple-0.6.5.1-HiBD1xXTeKX8ZHX6bZz96K
    resource-pool-0.2.3.2-49KsLH28AouCGCOaBY4afw
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD
    string-conversions-0.4.0.1-At29VEfYfYXoXdSzJB7Sz text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vault-0.3.1.5-8H3tTavQv2TDi1YBNlWJrz

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-postgresql-2.13.4.1-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent-postgresql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-postgresql
version:              2.13.4.1
visibility:           public
id:                   persistent-postgresql-2.13.4.1-25ySbfsE3nZHs0ijLCN0aT
key:                  persistent-postgresql-2.13.4.1-25ySbfsE3nZHs0ijLCN0aT
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  f2e8a765ad0ee55ef53b730d040f22bd
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.Internal
    Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.4.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.4.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/persistent-postgresql-2.13.4.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-postgresql
hs-libraries:         HSpersistent-postgresql-2.13.4.1-25ySbfsE3nZHs0ijLCN0aT
depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    conduit-1.3.6.1-xf7BUYu4FPC4jaCDr8wkD containers-0.6.7
    monad-logger-0.3.41-GLKFkWFEA4J84Ym1ok00m7 mtl-2.2.2
    persistent-2.14.5.1-H0aWpG3R5mf1tBvRk2nTxw
    postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1
    postgresql-simple-0.6.5.1-4ZpHJzwz4fOISQQrFG289c
    resource-pool-0.2.3.2-49KsLH28AouCGCOaBY4afw
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD
    string-conversions-0.4.0.1-At29VEfYfYXoXdSzJB7Sz text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vault-0.3.1.5-8H3tTavQv2TDi1YBNlWJrz

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
